@@ -9,7 +9,10 @@ OC.L10N.register(
     "Please see Nextcloud server log for details." : "נא לעיין ביומן השרת של Nextcloud לפרטים נוספים.",
     "Deleted {title}" : "{title} נמחק",
     "Undo Delete" : "ביטול מחיקה",
+    "Note recovered" : "הפתק שוחזר",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו","{number} פתקים נמחקו"],
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
     "Settings" : "הגדרות",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
     "path to notes" : "נתיב לפתקיות",
